#ifndef GNOME_RADIO_INFO_H
#define GNOME_RADIO_INFO_H 1

#include <glib.h>
#include <gtk/gtk.h>

typedef struct _LocationInfo LocationInfo;
typedef struct _RadioInfo RadioInfo;
typedef struct _StreamInfo StreamInfo;
typedef struct _RadioWindow RadioWindow;

struct _RadioWindow {
	GtkWidget *window;
	gchar *window_title;
	gchar *text;
	gchar *uri;
};

struct _LocationInfo {
	double *lat;
	double *lon;
	gchar *city;
};

struct _RadioInfo {
	gchar *uri;
	LocationInfo *location;
	StreamInfo *stream;
	RadioInfo *next;
	RadioInfo *prev;
};

struct _StreamInfo {
	gchar *uri;
	StreamInfo *next;
	StreamInfo *prev;	
};

#endif /* GNOME_RADIO_INFO_H */
